==> haskell-nettle-0.3.0-206-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-nettle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 nettle
version:              0.3.0
visibility:           public
id:                   nettle-0.3.0-G72c3rFgPgR1SxYxKmyWWD
key:                  nettle-0.3.0-G72c3rFgPgR1SxYxKmyWWD
license:              MIT
copyright:            Stefan Bühler <stbuehler@web.de>
maintainer:           Stefan Bühler <stbuehler@web.de>
author:               Stefan Bühler <stbuehler@web.de>
homepage:             https://github.com/stbuehler/haskell-nettle
synopsis:             safe nettle binding
description:
    safe binding for the nettle (<http://www.lysator.liu.se/~nisse/nettle/nettle.html>) library.
    Tested with 3.4, might work with 3.2 (but not earlier).

category:             Cryptography
abi:                  90e249fb75d05a099d9924fd55a20e3c
exposed:              True
exposed-modules:
    Crypto.Nettle.CCM Crypto.Nettle.ChaChaPoly1305
    Crypto.Nettle.Ciphers Crypto.Nettle.HMAC Crypto.Nettle.Hash
    Crypto.Nettle.KeyedHash Crypto.Nettle.UMAC

hidden-modules:
    Crypto.Nettle.Ciphers.Internal Crypto.Nettle.Ciphers.ForeignImports
    Crypto.Nettle.Hash.ForeignImports Crypto.Nettle.Hash.Types
    Nettle.Utils

import-dirs:          /usr/lib/ghc-9.0.2/site-local/nettle-0.3.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/nettle-0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/nettle-0.3.0
hs-libraries:         HSnettle-0.3.0-G72c3rFgPgR1SxYxKmyWWD
extra-libraries:      nettle
depends:
    base-4.15.1.0 byteable-0.1.1-F5eQFmfGgxkLWRm11Wu8en
    bytestring-0.10.12.1
    crypto-cipher-types-0.0.9-5ILz6kxkbGMIFcBX39zea
    securemem-0.1.10-6QzN0fGwj6UJJ4P3JoJYKy
    tagged-0.8.6.1-79gYUUazit6EfoPS33FHdR

haddock-interfaces:   /usr/share/doc/haskell-nettle/html/nettle.haddock
haddock-html:         /usr/share/doc/haskell-nettle/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-nettle-0.3.0-223-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-nettle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 nettle
version:              0.3.0
visibility:           public
id:                   nettle-0.3.0-2cnZ9iKtm0MDdR0VmkRbCB
key:                  nettle-0.3.0-2cnZ9iKtm0MDdR0VmkRbCB
license:              MIT
copyright:            Stefan Bühler <stbuehler@web.de>
maintainer:           Stefan Bühler <stbuehler@web.de>
author:               Stefan Bühler <stbuehler@web.de>
homepage:             https://github.com/stbuehler/haskell-nettle
synopsis:             safe nettle binding
description:
    safe binding for the nettle (<http://www.lysator.liu.se/~nisse/nettle/nettle.html>) library.
    Tested with 3.4, might work with 3.2 (but not earlier).

category:             Cryptography
abi:                  4c7a58b05086a608674474d39274c884
exposed:              True
exposed-modules:
    Crypto.Nettle.CCM Crypto.Nettle.ChaChaPoly1305
    Crypto.Nettle.Ciphers Crypto.Nettle.HMAC Crypto.Nettle.Hash
    Crypto.Nettle.KeyedHash Crypto.Nettle.UMAC

hidden-modules:
    Crypto.Nettle.Ciphers.Internal Crypto.Nettle.Ciphers.ForeignImports
    Crypto.Nettle.Hash.ForeignImports Crypto.Nettle.Hash.Types
    Nettle.Utils

import-dirs:          /usr/lib/ghc-9.0.2/site-local/nettle-0.3.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/nettle-0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-nettle
hs-libraries:         HSnettle-0.3.0-2cnZ9iKtm0MDdR0VmkRbCB
extra-libraries:      nettle
depends:
    base-4.15.1.0 byteable-0.1.1-F5eQFmfGgxkLWRm11Wu8en
    bytestring-0.10.12.1
    crypto-cipher-types-0.0.9-Eb32mKWiXi08hJgQY526gG
    securemem-0.1.10-IqxMuGzWgkb4DS0vuOrIox
    tagged-0.8.6.1-79gYUUazit6EfoPS33FHdR

haddock-interfaces:   /usr/share/doc/haskell-nettle/html/nettle.haddock
haddock-html:         /usr/share/doc/haskell-nettle/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
